@@ -1,4 +1,4 @@
-from django.conf.urls import url
+from django.urls import path
 
 from two_factor.views import (
     BackupTokensView, DisableView, LoginView, PhoneDeleteView, PhoneSetupView,
@@ -6,51 +6,51 @@ from two_factor.views import (
 )
 
 core = [
-    url(
-        r'^two_factor/login/$',
+    path(
+        'two_factor/login/',
         LoginView.as_view(),
         name='login',
     ),
-    url(
-        r'^two_factor/setup/$',
+    path(
+        'two_factor/setup/',
         SetupView.as_view(),
         name='setup',
     ),
-    url(
-        r'^two_factor/qrcode/$',
+    path(
+        'two_factor/qrcode/',
         QRGeneratorView.as_view(),
         name='qr',
     ),
-    url(
-        r'^two_factor/setup/complete/$',
+    path(
+        'two_factor/setup/complete/',
         SetupCompleteView.as_view(),
         name='setup_complete',
     ),
-    url(
-        r'^two_factor/backup/tokens/$',
+    path(
+        'two_factor/backup/tokens/',
         BackupTokensView.as_view(),
         name='backup_tokens',
     ),
-    url(
-        r'^two_factor/backup/phone/register/$',
+    path(
+        'two_factor/backup/phone/register/',
         PhoneSetupView.as_view(),
         name='phone_create',
     ),
-    url(
-        r'^two_factor/backup/phone/unregister/<int:pk>/$',
+    path(
+        'two_factor/backup/phone/unregister/<int:pk>',
         PhoneDeleteView.as_view(),
         name='phone_delete',
     ),
 ]
 
 profile = [
-    url(
-        r'^two_factor/$',
+    path(
+        'two_factor/',
         ProfileView.as_view(),
         name='profile',
     ),
-    url(
-        r'^two_factor/disable/$',
+    path(
+        'two_factor/disable/',
         DisableView.as_view(),
         name='disable',
     ),
